Package: cffr
Title: Generate Citation File Format ('CFF') Metadata
Version: 1.4.2
Authors@R: c(
    person("Diego", "Hernangómez", , "diego.hernangomezherrero@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0001-8457-4658")),
    person("João", "Martins", role = "rev",
           comment = c(ORCID = "0000-0001-7961-4280")),
    person("Scott", "Chamberlain", role = "rev",
           comment = c(ORCID = "0000-0003-1444-9135"))
  )
Description: Citation File Format ('CFF') version 1.2.0
    <doi:10.5281/zenodo.5171937> is a human- and machine-readable file
    format for software citation metadata. Core utilities generate, read,
    write and validate Citation File Format metadata for 'R' packages.
License: GPL (>= 3)
URL: https://docs.ropensci.org/cffr/, https://github.com/ropensci/cffr
BugReports: https://github.com/ropensci/cffr/issues
Depends: R (>= 4.1.0)
Imports: cli (>= 2.0.0), desc (>= 1.3.0), jsonlite (>= 1.7.2),
        jsonvalidate (>= 1.1.0), tools, utils, yaml (>= 2.2.1)
Suggests: bibtex (>= 0.5.0), knitr, lifecycle, quarto, rmarkdown,
        testthat (>= 3.3.0), usethis, withr
VignetteBuilder: quarto
Config/Needs/website: devtools
Config/roxygen2/markdown: TRUE
Config/roxygen2/version: 8.1.0
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
LazyData: true
X-schema.org-isPartOf: https://ropensci.org
X-schema.org-keywords: attribution, citation, credit, citation-files,
        cff, metadata, citation-file-format, cran, r, r-package,
        ropensci, rstats, r-cran
NeedsCompilation: no
Packaged: 2026-08-24 11:32:20 UTC; diego
Author: Diego Hernangómez [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-8457-4658>),
  João Martins [rev] (ORCID: <https://orcid.org/0000-0001-7961-4280>),
  Scott Chamberlain [rev] (ORCID:
    <https://orcid.org/0000-0003-1444-9135>)
Maintainer: Diego Hernangómez <diego.hernangomezherrero@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-24 12:10:02 UTC
Built: R 4.6.1; ; 2026-08-24 13:01:41 UTC; unix
