Type: Package
Package: manypersons
Title: A lot of persons
Version: 0.1.6
Authors@R:
    c(person(given = "Diego",
             family = "Hernangómez",
             role = c("aut", "cre"),
             email = "fake@gmail.com",
             comment = c(ORCID = "0000-0001-8457-4658", email = "error",
             "not-valid" = "error")),
      person(given = "Joe",
             family = "Doe",
             role = "aut",
             email = "I am a wrong email",
             comment = c(affiliation = "This One", country = "ES",
             "date-end" = "error")),
      person(given = "Pepe",
             family = "Doe",
             role = "aut",
             email = "fake@gmail.com",
             comment = "error"),
      person(given = "I am an entity",
             role = c("cre"),
             comment = c("date-end" = "2020-01-01", affiliation = "error")),
      person(given = "ERROR entity",
             role = "cph",
             comment = "for the administrative boundaries."),
      person(given = "ERROR",
             family = "person",
             role = "cph",
             comment = c(ORCID = "0000-0003-2042-7063", "for the gisco_countrycode dataset.")))
Description: Overkill desc with many persons. Try this
License: GPL-3
URL: https://github.com/many/persons,
    https://many.github.io/persons
BugReports: https://github.com/many/persons/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1.9000
X-schema.org-keywords: metadata, cffr, ropensci, citation,
    credit, linked-data, one, one, two
