Package: rgeos
Title: Interface to Geometry Engine - Open Source ('GEOS')
Version: 0.5-7
Date: 2020-09-07
Depends: R (>= 3.3.0), methods, sp (>= 1.1-0)
Imports: utils, stats, graphics
LinkingTo: sp
Suggests: maptools (>= 0.8-5), testthat, XML, maps, rgdal
NeedsCompilation: yes
LazyLoad: yes
Description: Interface to Geometry Engine - Open Source ('GEOS') using the C 'API' for topology operations on geometries. Please note that 'rgeos' will be retired by the end of 2023, plan transition to sf functions using 'GEOS' at your earliest convenience. The 'GEOS' library is external to the package, and, when installing the package from source, must be correctly installed first. Windows and Mac Intel OS X binaries are provided on 'CRAN'. ('rgeos' >= 0.5-1): Up to and including 'GEOS' 3.7.1, topological operations succeeded with some invalid geometries for which the same operations fail from and including 'GEOS' 3.7.2. The 'checkValidity=' argument defaults and structure have been changed, from default FALSE to integer default '0L' for 'GEOS' < 3.7.2 (no check), '1L' 'GEOS' >= 3.7.2 (check and warn). A value of '2L' is also provided that may be used, assigned globally using 'set_RGEOS_CheckValidity(2L)', or locally using the 'checkValidity=2L' argument, to attempt zero-width buffer repair if invalid geometries are found. The previous default (FALSE, now '0L') is fastest and used for 'GEOS' < 3.7.2, but will not warn users of possible problems before the failure of topological operations that previously succeeded. From 'GEOS' 3.8.0, repair of geometries may also be attempted using 'gMakeValid()', which may, however, return a collection of geometries of different types.
Authors@R: c(
	person("Roger", "Bivand", role = c("cre", "aut"), email = "Roger.Bivand@nhh.no", comment=c(ORCID="0000-0003-2392-6140")),
	person("Colin", "Rundel", role = "aut"),
	person("Edzer", "Pebesma", role = "ctb"),
	person("Rainer", "Stuetz", role = "ctb"),
	person("Karl Ove", "Hufthammer", role = "ctb"),
        person("Patrick", "Giraudoux", role = "ctb"),
        person("Martin", "Davis", role = c("cph", "ctb")),
        person("Sandro", "Santilli", role = c("cph", "ctb")))
License: GPL (>= 2)
URL: https://r-forge.r-project.org/projects/rgeos/
        https://trac.osgeo.org/geos/
        http://rgeos.r-forge.r-project.org/index.html
SystemRequirements: GEOS (>= 3.2.0); for building from source: GEOS
        from http://trac.osgeo.org/geos/; GEOS OSX frameworks built by
        William Kyngesburye at http://www.kyngchaos.com/ may be used
        for source installs on OSX.
RoxygenNote: 6.1.1
Packaged: 2021-09-07 13:14:38 UTC; rsb
Author: Roger Bivand [cre, aut] (<https://orcid.org/0000-0003-2392-6140>),
  Colin Rundel [aut],
  Edzer Pebesma [ctb],
  Rainer Stuetz [ctb],
  Karl Ove Hufthammer [ctb],
  Patrick Giraudoux [ctb],
  Martin Davis [cph, ctb],
  Sandro Santilli [cph, ctb]
Maintainer: Roger Bivand <Roger.Bivand@nhh.no>
Repository: CRAN
Date/Publication: 2020-09-07 14:00:05 UTC
Built: R 4.1.1; x86_64-w64-mingw32; 2021-09-09 08:49:58 UTC; windows
Archs: i386, x64
