Package: basicdesc
Type: Package
Title: A Basic Description
Version: 0.1.6
Author: Marc Basic
Maintainer: Marc Basic <marcbasic@gmail.com>
Description: A very basic description. Should parse without problems.
License: GPL-3
URL: https://github.com/basic/package, https://basic.github.io/package
BugReports: https://github.com/basic/package/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1.9000
