Package: wrongurls
Type: Package
Title: Generate CodeMeta Metadata for R Packages
Version: 0.1.0
Author: Carl Boettiger [aut, cre, cph] <cboettig@gmail.com> (https://orcid.org/0000-0002-1642-628X)
Maintainer: Carl Boettiger <cboettig@gmail.com> (https://orcid.org/0000-0002-1642-628X)
Description: Codemeta defines a 'JSON-LD' format for describing software metadata.
    This package provides utilities to generate, parse, and modify codemeta.jsonld
    files automatically for R packages.
License: MIT + file LICENSE
URL: thisisnotandurl,
     https://httpbin.org/status/429,
     https://www.github.es/ropensci/codemeta,
BugReports: https://httpbin.org/status/404
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1
Depends: R (>= 3.0.0)
Imports: jsonlite (>= 1.3),
    jsonld,
    git2r,
    devtools,
    methods
Suggests: testthat,
    jsonvalidate,
    covr,
    knitr,
    rmarkdown,
    httr,
    magrittr,
    readr,
    xml2
VignetteBuilder: knitr
X-schema.org-keywords: metadata, codemeta, ropensci, citation, credit, linked-data
X-schema.org-isPartOf: https://ropensci.org
