Type: Package
Package: codemetar
Title: Generate 'CodeMeta' Metadata for R Packages
Version: 0.1.6
Author: Jane Doo
Maintainer: John Ok <email@email.edu>, Jane Doe <email2@email.edu>
Description: The 'Codemeta' Project defines a 'JSON-LD' format for
    describing software metadata, as detailed at
    <https://codemeta.github.io>. This package provides utilities to
    generate, parse, and modify 'codemeta.json' files automatically for R
    packages, as well as tools and examples for working with
    'codemeta.json' 'JSON-LD' more generally.
License: GPL-3
URL: https://github.com/ropensci/codemetar,
    https://ropensci.github.io/codemetar
BugReports: https://github.com/ropensci/codemetar/issues
Depends:
    R (>= 3.0.0)
Imports:
    crul,
    desc,
    devtools,
    gh,
    git2r,
    jsonld,
    jsonlite (>= 1.3),
    memoise,
    methods,
    purrr,
    readr,
    sessioninfo,
    stats,
    stringi,
    stringr,
    tibble,
    usethis,
    whisker
Suggests:
    covr,
    dplyr (>= 0.7.0),
    jsonvalidate,
    knitr,
    magrittr,
    printr,
    rmarkdown,
    testthat,
    xml2
VignetteBuilder:
    knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 6.0.1.9000

