Package: options
Title: Simple, Consistent Package Options
Version: 0.3.0
Authors@R:
    person(
      "Doug",
      "Kelkhoff",
      email = "doug.kelkhoff@gmail.com",
      role = c("aut", "cre")
    )
Description:
    Simple mechanisms for defining and interpreting package options. Provides
    helpers for interpreting environment variables, global options, defining
    default values and more.
License:
    MIT + file LICENSE
URL:
    https://dgkf.github.io/options/,
    https://codeberg.org/dgkf/options
BugReports:
    https://codeberg.org/dgkf/options/issues
Imports:
    utils
Suggests:
    crayon,
    knitr,
    rmarkdown,
    roxygen2,
    rcmdcheck,
    pkgload,
    withr,
    testthat (>= 3.0.0)
Config/Needs/website:
    pkgdown
Roxygen:
    list(markdown = TRUE)
VignetteBuilder:
    knitr
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
Config/testthat/edition: 3
