Package: quint
Type: Package
Title: Qualitative Interaction Trees
Version: 2.2.2
Date: 2022-07-01
Authors@R: c(person(given = "Elise", family = "Dusseldorp", role =
        c("aut", "cre","cph"), email = "elise.dusseldorp@fsw.leidenuniv.nl"),
        person("Lisa","Doove",role=c("aut"),email="lisa.doove@kuleuven.be"),
	person("Jeanne", "van de  Put", role = "aut", email="jmms1991@gmail.com"),
	person("Cor","Ninaber",comment="supported with the plot function",role="ctb"),
        person(given = "Iven", family = "Van Mechelen", role = c("aut","cph"), email
        = "iven.vanmechelen@kuleuven.be"),
        person(given = "Juan", family = "Claramunt Gonzalez", role = c("aut"), email
        = "j.claramunt.gonzalez@fsw.leidenuniv.nl"))
Maintainer: Elise Dusseldorp <elise.dusseldorp@fsw.leidenuniv.nl>
Description: Grows a qualitative interaction tree. Quint is a tool for subgroup analysis, suitable for data from a two-arm randomized controlled trial. More information in Dusseldorp, E., Doove, L., & Van Mechelen, I. (2016) <doi:10.3758/s13428-015-0594-z>.
Depends: R (>= 3.0.2)
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
License: GPL (>= 3)
LazyData: TRUE
RoxygenNote: 7.1.1
Author: Elise Dusseldorp [aut, cre, cph],
  Lisa Doove [aut],
  Jeanne van de Put [aut],
  Cor Ninaber [ctb] (supported with the plot function),
  Iven Van Mechelen [aut, cph],
  Juan Claramunt Gonzalez [aut]
NeedsCompilation: no
Packaged: 2022-07-01 11:24:25 UTC; jclaramunt
Repository: CRAN
Date/Publication: 2022-07-01 21:30:02 UTC
Built: R 4.6.0; ; 2026-04-29 18:25:19 UTC; windows
RemoteType: standard
RemotePkgRef: quint
RemoteRef: quint
RemoteRepos: http://cran.rstudio.com
RemoteSha: 2.2.2
