# Generated by roxygen2: do not edit by hand

S3method("[",cff_pers_lst)
S3method("[",cff_ref_lst)
S3method(as.data.frame,cff)
S3method(as.data.frame,cff_pers)
S3method(as.data.frame,cff_pers_lst)
S3method(as.data.frame,cff_ref)
S3method(as.data.frame,cff_ref_lst)
S3method(as.list,cff)
S3method(as.person,cff)
S3method(as.person,cff_pers)
S3method(as.person,cff_pers_lst)
S3method(as.person,cff_ref)
S3method(as.person,cff_ref_lst)
S3method(as_bibentry,"NULL")
S3method(as_bibentry,cff)
S3method(as_bibentry,cff_ref)
S3method(as_bibentry,cff_ref_lst)
S3method(as_bibentry,character)
S3method(as_bibentry,default)
S3method(as_bibentry,list)
S3method(as_cff,Bibtex)
S3method(as_cff,bibentry)
S3method(as_cff,default)
S3method(as_cff,list)
S3method(as_cff,person)
S3method(as_cff_person,character)
S3method(as_cff_person,default)
S3method(as_cff_person,person)
S3method(c,cff)
S3method(head,cff)
S3method(print,cff)
S3method(tail,cff)
S3method(toBibtex,cff)
S3method(toBibtex,cff_pers)
S3method(toBibtex,cff_pers_lst)
S3method(toBibtex,cff_ref)
S3method(toBibtex,cff_ref_lst)
export(as.cff)
export(as_bibentry)
export(as_cff)
export(as_cff_person)
export(cff)
export(cff_create)
export(cff_extract_to_bibtex)
export(cff_from_bibtex)
export(cff_gha_update)
export(cff_git_hook_install)
export(cff_git_hook_remove)
export(cff_modify)
export(cff_parse_citation)
export(cff_parse_person)
export(cff_parse_person_bibtex)
export(cff_read)
export(cff_read_bib)
export(cff_read_bib_text)
export(cff_read_cff_citation)
export(cff_read_citation)
export(cff_read_description)
export(cff_schema_definitions_entity)
export(cff_schema_definitions_person)
export(cff_schema_definitions_refs)
export(cff_schema_keys)
export(cff_schema_keys_license)
export(cff_to_bibtex)
export(cff_validate)
export(cff_write)
export(cff_write_bib)
export(cff_write_citation)
export(encoded_utf_to_latex)
export(write_bib)
export(write_citation)
importFrom(tools,encoded_text_to_latex)
importFrom(utils,
  as.person,
  available.packages,
  bibentry,
  capture.output,
  citation,
  download.file,
  head,
  installed.packages,
  modifyList,
  packageDescription,
  person,
  read.csv,
  tail,
  toBibtex
)
