list(
  rd_family_title = list(
    core = "Other core functions of \\CRANpkg{cffr}:",
    reading = "Other functions for reading external files:",
    writing = "Other functions for creating external files:",
    bibtex = "Other functions for working with BibTeX format:",
    schemas = "Other CFF schemas:",
    git = "Other Git/GitHub helpers provided by \\CRANpkg{cffr}:",
    deprecated = "Other deprecated functions:",
    s3method = "Coercing between \\strong{R} classes with \\strong{S3 Methods}:"
  )
)
