#' @keywords internal
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end
NULL

# Import namespace directives
#' @importFrom utils download.file as.person read.csv person capture.output
#' @importFrom utils installed.packages packageDescription citation
#' @importFrom utils available.packages modifyList toBibtex bibentry head tail
NULL
