#' The `cff` class
#' @encoding UTF-8
#'
#' @rdname cff_class
#' @name cff_class
#' @aliases cff_ref cff_ref_lst cff_pers cff_pers_lst
#'
#' @keywords internal
#'
#' @family s3method
#'
#' @description
#'
#' ```{r child = "man/chunks/cffclass.Rmd"}
#' ```
#'
#' @references
#'
#' - Wickham H (2019). "S3." In _Advanced R_, 2nd edition.
#'   Chapman and Hall/CRC. \doi{10.1201/9781351201315},
#'   <https://adv-r.hadley.nz/s3.html>.
NULL
