# Errors

    Code
      cff_write_bib(1:4)
    Condition
      Error in `cff_write_bib()`:
      ! `x` should be a <bibentry> object, not a <integer> object.

# Errors citation

    Code
      cff_write_citation(1:4)
    Condition
      Error in `cff_write_citation()`:
      ! `x` should be a <bibentry> object, not a <integer> object.

