# Keys snapshot

    Code
      cff_schema_keys(FALSE)
    Output
       [1] "cff-version"         "message"             "type"               
       [4] "license"             "title"               "version"            
       [7] "doi"                 "identifiers"         "abstract"           
      [10] "authors"             "preferred-citation"  "repository"         
      [13] "repository-artifact" "repository-code"     "commit"             
      [16] "url"                 "date-released"       "contact"            
      [19] "keywords"            "references"          "license-url"        

