# Merge all DESCRIPTION files with CITATION_basic

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "basicdesc" in publications use:'
      type: software
      title: 'basicdesc: A Basic Description'
      version: 0.1.6
      authors:
      - family-names: Basic
        given-names: Marc
        email: marcbasic@gmail.com
      abstract: A very basic description. Should parse without problems.
      repository-code: https://github.com/basic/package
      url: https://basic.github.io/package
      contact:
      - family-names: Basic
        given-names: Marc
        email: marcbasic@gmail.com
      license: GPL-3.0-only
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "basicdesc" in publications use:'
      type: software
      title: 'basicdesc: A Basic Description'
      version: 0.1.6
      authors:
      - family-names: Basic
        given-names: Marc
        email: marcbasic@gmail.com
      abstract: A very basic description. Should parse without problems.
      repository-code: https://github.com/basic/package
      url: https://basic.github.io/package
      contact:
      - family-names: Basic
        given-names: Marc
        email: marcbasic@gmail.com
      license: GPL-3.0-only
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "basicdescdate" in publications use:'
      type: software
      title: 'basicdescdate: A Basic Description with Date'
      version: 0.1.6
      authors:
      - family-names: Basic
        given-names: Marc
        email: marcbasic@gmail.com
      abstract: A very basic description. Should parse without problems. I have a Date
      repository-code: https://github.com/basic/package
      url: https://basic.github.io/package
      date-released: '1999-01-01'
      contact:
      - family-names: Basic
        given-names: Marc
        email: marcbasic@gmail.com
      license: GPL-3.0-only
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "GenomicRanges" in publications use:'
      type: software
      title: 'GenomicRanges: Representation and manipulation of genomic intervals'
      version: 1.51.4
      authors:
      - family-names: Aboyoun
        given-names: Patrick
      - family-names: Pagès
        given-names: Hervé
        email: hpages.on.github@gmail.com
      - family-names: Lawrence
        given-names: Michael
      abstract: The ability to efficiently represent and manipulate genomic annotations
        and alignments is playing a central role when it comes to analyzing high-throughput
        sequencing data (a.k.a. NGS data). The GenomicRanges package defines general purpose
        containers for storing and manipulating genomic intervals and variables defined
        along a genome. More specialized containers for representing and manipulating short
        alignments against a reference genome, or a matrix-like summarization of an experiment,
        are defined in the GenomicAlignments and SummarizedExperiment packages, respectively.
        Both packages build on top of the GenomicRanges infrastructure.
      repository: https://bioconductor.org/
      repository-code: https://github.com/Bioconductor/GenomicRanges
      url: https://bioconductor.org/packages/GenomicRanges
      date-released: '2022-12-15'
      contact:
      - family-names: Pagès
        given-names: Hervé
        email: hpages.on.github@gmail.com
      license: Artistic-2.0
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "options" in publications use:'
      type: software
      title: 'options: Simple, Consistent Package Options'
      version: 0.3.0
      authors:
      - family-names: Kelkhoff
        given-names: Doug
        email: doug.kelkhoff@gmail.com
      abstract: Simple mechanisms for defining and interpreting package options. Provides
        helpers for interpreting environment variables, global options, defining default
        values and more.
      repository: https://CRAN.R-project.org/package=options
      repository-code: https://codeberg.org/dgkf/options
      url: https://dgkf.github.io/options/
      contact:
      - family-names: Kelkhoff
        given-names: Doug
        email: doug.kelkhoff@gmail.com
      license: MIT
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: doi
        value: 10.32614/CRAN.package.options
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "codemetar" in publications use:'
      type: software
      title: 'codemetar: Generate ''CodeMeta'' Metadata for R Packages'
      version: 0.1.6
      authors:
      - family-names: Boettiger
        given-names: Carl
        email: cboettig@gmail.com
        orcid: https://orcid.org/0000-0002-1642-628X
      - family-names: Salmon
        given-names: Maëlle
        orcid: https://orcid.org/0000-0002-2815-0399
      abstract: The 'Codemeta' Project defines a 'JSON-LD' format for describing software
        metadata, as detailed at <https://codemeta.github.io>. This package provides utilities
        to generate, parse, and modify 'codemeta.json' files automatically for R packages,
        as well as tools and examples for working with 'codemeta.json' 'JSON-LD' more generally.
      repository: https://CRAN.R-project.org/package=codemetar
      repository-code: https://gitlab.com/ninijay/methoden
      url: https://ropensci.github.io/codemetar
      contact:
      - family-names: Boettiger
        given-names: Carl
        email: cboettig@gmail.com
        orcid: https://orcid.org/0000-0002-1642-628X
      keywords:
      - metadata
      - codemeta
      - ropensci
      - citation
      - credit
      - linked-data
      license: GPL-3.0-only
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: doi
        value: 10.32614/CRAN.package.codemetar
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "manypersons" in publications use:'
      type: software
      title: 'manypersons: A lot of persons'
      version: 0.1.6
      authors:
      - family-names: Hernangómez
        given-names: Diego
        email: fake@gmail.com
        orcid: https://orcid.org/0000-0001-8457-4658
      - family-names: Doe
        given-names: Joe
        affiliation: This One
        country: ES
      - family-names: Doe
        given-names: Pepe
        email: fake@gmail.com
      - name: I am an entity
        date-end: '2020-01-01'
      abstract: Overkill desc with many persons. Try this
      repository-code: https://github.com/many/persons
      url: https://many.github.io/persons
      contact:
      - family-names: Hernangómez
        given-names: Diego
        email: fake@gmail.com
        orcid: https://orcid.org/0000-0001-8457-4658
      - name: I am an entity
        date-end: '2020-01-01'
      keywords:
      - metadata
      - cffr
      - ropensci
      - citation
      - credit
      - linked-data
      - one
      - two
      license: GPL-3.0-only
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "manyurls" in publications use:'
      type: software
      title: 'manyurls: A lot of urls'
      version: 0.1.6
      authors:
      - family-names: Basic
        given-names: Marc
        email: marcbasic@gmail.com
      abstract: This package has many urls. Specifically, 1 Bug Reports and 6 URLs. Expected
        is to have 1 repository-code, 1 url and 3 URLs, since there is 1 duplicate and 1
        invalid url.
      repository-code: https://github.com/test/package
      url: https://test.github.io/package/
      contact:
      - family-names: Basic
        given-names: Marc
        email: marcbasic@gmail.com
      license: GPL-3.0-only
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: url
        value: https://r-forge.r-project.org/projects/test/
      - type: url
        value: http://google.ru
      - type: url
        value: https://gitlab.com/r-packages/behaviorchange
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "codemetar" in publications use:'
      type: software
      title: 'codemetar: Generate ''CodeMeta'' Metadata for R Packages'
      version: 0.1.6
      authors:
      - family-names: Boettiger
        given-names: Carl
        email: cboettig@gmail.com
        orcid: https://orcid.org/0000-0002-1642-628X
      - family-names: Salmon
        given-names: Maëlle
        orcid: https://orcid.org/0000-0002-2815-0399
      abstract: The 'Codemeta' Project defines a 'JSON-LD' format for describing software
        metadata, as detailed at <https://codemeta.github.io>. This package provides utilities
        to generate, parse, and modify 'codemeta.json' files automatically for R packages,
        as well as tools and examples for working with 'codemeta.json' 'JSON-LD' more generally.
      repository: https://CRAN.R-project.org/package=codemetar
      contact:
      - family-names: Boettiger
        given-names: Carl
        email: cboettig@gmail.com
        orcid: https://orcid.org/0000-0002-1642-628X
      keywords:
      - metadata
      - codemeta
      - ropensci
      - citation
      - credit
      - linked-data
      license: GPL-3.0-only
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: doi
        value: 10.32614/CRAN.package.codemetar
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "idonthavencoding" in publications use:'
      type: software
      title: 'idonthavencoding: No Encoding'
      version: 0.1.6
      authors:
      - family-names: Basic
        given-names: Marc
        email: marcbasic@gmail.com
        orcid: https://orcid.org/0000-0000-0000-001X
      abstract: I don't have Encoding field. Should parse without problems. Maybe some warning,
        but because the missing Encoding field.
      repository-code: https://github.com/idonthavencoding/package
      url: https://idonthavencoding.github.io/package
      contact:
      - family-names: Basic
        given-names: Marc
        email: marcbasic@gmail.com
        orcid: https://orcid.org/0000-0000-0000-001X
      license: GPL-3.0-only
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "resmush" in publications use:'
      type: software
      title: 'resmush: Optimize and Compress Image Files with ''reSmush.it'''
      version: 0.1.0
      authors:
      - family-names: Hernangómez
        given-names: Diego
        email: diego.hernangomezherrero@gmail.com
        orcid: https://orcid.org/0000-0001-8457-4658
      abstract: Compress local and online images using the 'reSmush.it' API service <https://resmush.it/>.
      repository: https://CRAN.R-project.org/package=resmush
      repository-code: https://github.com/dieghernan/resmush
      url: https://dieghernan.github.io/resmush/
      date-released: '2024-02-02'
      contact:
      - family-names: Hernangómez
        given-names: Diego
        email: diego.hernangomezherrero@gmail.com
        orcid: https://orcid.org/0000-0001-8457-4658
      keywords:
      - r
      - compress-images
      - optimize-images
      - resmushit
      - api
      license: MIT
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: doi
        value: 10.32614/CRAN.package.resmush
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "quint" in publications use:'
      type: software
      title: 'quint: Qualitative Interaction Trees'
      version: 2.2.2
      authors:
      - family-names: Dusseldorp
        given-names: Elise
        email: elise.dusseldorp@fsw.leidenuniv.nl
      - family-names: Doove
        given-names: Lisa
        email: lisa.doove@kuleuven.be
      - family-names: Put
        given-names: Jeanne
        name-particle: van de
        email: jmms1991@gmail.com
      - family-names: Van Mechelen
        given-names: Iven
        email: iven.vanmechelen@kuleuven.be
      - family-names: Claramunt Gonzalez
        given-names: Juan
        email: j.claramunt.gonzalez@fsw.leidenuniv.nl
      abstract: Grows a qualitative interaction tree. Quint is a tool for subgroup analysis,
        suitable for data from a two-arm randomized controlled trial. More information in
        Dusseldorp, E., Doove, L., & Van Mechelen, I. (2016) <https://doi.org/10.3758/s13428-015-0594-z>.
      repository: https://CRAN.R-project.org/package=quint
      date-released: '2022-07-01'
      contact:
      - family-names: Dusseldorp
        given-names: Elise
        email: elise.dusseldorp@fsw.leidenuniv.nl
      license: GPL-3.0-or-later
      commit: 2.2.2
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: doi
        value: 10.32614/CRAN.package.quint
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "codemetar" in publications use:'
      type: software
      title: 'codemetar: Generate ''CodeMeta'' Metadata for R Packages'
      version: 0.3.5
      authors:
      - family-names: Boettiger
        given-names: Carl
        email: cboettig@gmail.com
        orcid: https://orcid.org/0000-0002-1642-628X
      - family-names: Salmon
        given-names: Maëlle
        orcid: https://orcid.org/0000-0002-2815-0399
      abstract: The 'Codemeta' Project defines a 'JSON-LD' format for describing software
        metadata, as detailed at <https://codemeta.github.io>. This package provides utilities
        to generate, parse, and modify 'codemeta.json' files automatically for R packages,
        as well as tools and examples for working with 'codemeta.json' 'JSON-LD' more generally.
      repository: https://ropensci.r-universe.dev
      repository-code: https://github.com/ropensci/codemetar
      url: https://docs.ropensci.org/codemetar/
      date-released: '2024-02-09'
      contact:
      - family-names: Boettiger
        given-names: Carl
        email: cboettig@gmail.com
        orcid: https://orcid.org/0000-0002-1642-628X
      keywords:
      - metadata
      - codemeta
      - ropensci
      - citation
      - credit
      - linked-data
      license: GPL-3.0-only
      commit: bdd9a29d7eabcc43c3195fe461f884932eba763c
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: doi
        value: 10.32614/CRAN.package.codemetar
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "rgeos" in publications use:'
      type: software
      title: 'rgeos: Interface to Geometry Engine - Open Source (''GEOS'')'
      version: 0.5-7
      authors:
      - family-names: Bivand
        given-names: Roger
        email: Roger.Bivand@nhh.no
        orcid: https://orcid.org/0000-0003-2392-6140
      - family-names: Rundel
        given-names: Colin
      abstract: 'Interface to Geometry Engine - Open Source (''GEOS'') using the C ''API''
        for topology operations on geometries. Please note that ''rgeos'' will be retired
        by the end of 2023, plan transition to sf functions using ''GEOS'' at your earliest
        convenience. The ''GEOS'' library is external to the package, and, when installing
        the package from source, must be correctly installed first. Windows and Mac Intel
        OS X binaries are provided on ''CRAN''. (''rgeos'' >= 0.5-1): Up to and including
        ''GEOS'' 3.7.1, topological operations succeeded with some invalid geometries for
        which the same operations fail from and including ''GEOS'' 3.7.2. The ''checkValidity=''
        argument defaults and structure have been changed, from default FALSE to integer
        default ''0L'' for ''GEOS'' < 3.7.2 (no check), ''1L'' ''GEOS'' >= 3.7.2 (check
        and warn). A value of ''2L'' is also provided that may be used, assigned globally
        using ''set_RGEOS_CheckValidity(2L)'', or locally using the ''checkValidity=2L''
        argument, to attempt zero-width buffer repair if invalid geometries are found. The
        previous default (FALSE, now ''0L'') is fastest and used for ''GEOS'' < 3.7.2, but
        will not warn users of possible problems before the failure of topological operations
        that previously succeeded. From ''GEOS'' 3.8.0, repair of geometries may also be
        attempted using ''gMakeValid()'', which may, however, return a collection of geometries
        of different types.'
      repository: https://CRAN.R-project.org/package=rgeos
      repository-code: https://r-forge.r-project.org/projects/rgeos/
      url: https://trac.osgeo.org/geos/
      date-released: '2020-09-07'
      contact:
      - family-names: Bivand
        given-names: Roger
        email: Roger.Bivand@nhh.no
        orcid: https://orcid.org/0000-0003-2392-6140
      license: GPL-2.0-or-later
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: url
        value: http://rgeos.r-forge.r-project.org/index.html
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "surveillance" in publications use:'
      type: software
      title: 'surveillance: Temporal and Spatio-Temporal Modeling and Monitoring of Epidemic
        Phenomena'
      version: 1.19.1
      authors:
      - family-names: Höhle
        given-names: Michael
        email: hoehle@math.su.se
        orcid: https://orcid.org/0000-0002-0423-6702
      - family-names: Meyer
        given-names: Sebastian
        email: seb.meyer@fau.de
        orcid: https://orcid.org/0000-0002-1791-9449
      - family-names: Paul
        given-names: Michaela
      abstract: Statistical methods for the modeling and monitoring of time series of counts,
        proportions and categorical data, as well as for the modeling of continuous-time
        point processes of epidemic phenomena. The monitoring methods focus on aberration
        detection in count data time series from public health surveillance of communicable
        diseases, but applications could just as well originate from environmetrics, reliability
        engineering, econometrics, or social sciences. The package implements many typical
        outbreak detection procedures such as the (improved) Farrington algorithm, or the
        negative binomial GLR-CUSUM method of Höhle and Paul (2008) <https://doi.org/10.1016/j.csda.2008.02.015>.
        A novel CUSUM approach combining logistic and multinomial logistic modeling is also
        included. The package contains several real-world data sets, the ability to simulate
        outbreak data, and to visualize the results of the monitoring in a temporal, spatial
        or spatio-temporal fashion. A recent overview of the available monitoring procedures
        is given by Salmon et al. (2016) <https://doi.org/10.18637/jss.v070.i10>. For the
        retrospective analysis of epidemic spread, the package provides three endemic-epidemic
        modeling frameworks with tools for visualization, likelihood inference, and simulation.
        hhh4() estimates models for (multivariate) count time series following Paul and
        Held (2011) <https://doi.org/10.1002/sim.4177> and Meyer and Held (2014) <https://doi.org/10.1214/14-AOAS743>.
        twinSIR() models the susceptible-infectious-recovered (SIR) event history of a fixed
        population, e.g, epidemics across farms or networks, as a multivariate point process
        as proposed by Höhle (2009) <https://doi.org/10.1002/bimj.200900050>. twinstim()
        estimates self-exciting point process models for a spatio-temporal point pattern
        of infective events, e.g., time-stamped geo-referenced surveillance data, as proposed
        by Meyer et al. (2012) <https://doi.org/10.1111/j.1541-0420.2011.01684.x>. A recent
        overview of the implemented space-time modeling frameworks for epidemic phenomena
        is given by Meyer et al. (2017) <https://doi.org/10.18637/jss.v077.i11>.
      repository: https://CRAN.R-project.org/package=surveillance
      repository-code: https://surveillance.R-Forge.R-project.org/
      url: https://surveillance.R-Forge.R-project.org/
      date-released: '2021-03-30'
      contact:
      - family-names: Meyer
        given-names: Sebastian
        email: seb.meyer@fau.de
        orcid: https://orcid.org/0000-0002-1791-9449
      license: GPL-2.0-only
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: doi
        value: 10.32614/CRAN.package.surveillance
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "MomTrunc" in publications use:'
      type: software
      title: 'MomTrunc: Moments of Folded and Doubly Truncated Multivariate Distributions'
      version: '6.0'
      authors:
      - family-names: Galarza
        given-names: Christian E.
        email: cgalarza88@gmail.com
        orcid: https://orcid.org/0000-0002-4818-6006
      - family-names: Lachos
        given-names: Victor H.
        email: hlachos@gmail.com
        orcid: https://orcid.org/0000-0002-7239-2459
      abstract: It computes arbitrary products moments (mean vector and variance-covariance
        matrix), for some double truncated (and folded) multivariate distributions. These
        distributions belong to the family of selection elliptical distributions, which
        includes well known skewed distributions as the unified skew-t distribution (SUT)
        and its particular cases as the extended skew-t (EST), skew-t (ST) and the symmetric
        student-t (T) distribution. Analogous normal cases unified skew-normal (SUN), extended
        skew-normal (ESN), skew-normal (SN), and symmetric normal (N) are also included.
        Density, probabilities and random deviates are also offered for these members.
      repository: https://CRAN.R-project.org/package=MomTrunc
      date-released: '2022-06-15'
      contact:
      - family-names: Galarza
        given-names: Christian E.
        email: cgalarza88@gmail.com
        orcid: https://orcid.org/0000-0002-4818-6006
      license: GPL-2.0-or-later
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: doi
        value: 10.32614/CRAN.package.MomTrunc
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "codemetar" in publications use:'
      type: software
      title: 'codemetar: Generate ''CodeMeta'' Metadata for R Packages'
      version: 0.1.6
      authors:
      - family-names: Ok
        given-names: John
        email: email@email.edu
      - family-names: Doe
        given-names: Jane
        email: email2@email.edu
      - family-names: Doo
        given-names: Jane
      abstract: The 'Codemeta' Project defines a 'JSON-LD' format for describing software
        metadata, as detailed at <https://codemeta.github.io>. This package provides utilities
        to generate, parse, and modify 'codemeta.json' files automatically for R packages,
        as well as tools and examples for working with 'codemeta.json' 'JSON-LD' more generally.
      repository: https://CRAN.R-project.org/package=codemetar
      repository-code: https://github.com/ropensci/codemetar
      url: https://ropensci.github.io/codemetar
      contact:
      - family-names: Ok
        given-names: John
        email: email@email.edu
      - family-names: Doe
        given-names: Jane
        email: email2@email.edu
      license: GPL-3.0-only
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: doi
        value: 10.32614/CRAN.package.codemetar
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

---

    Code
      merged
    Output
      cff-version: 1.2.0
      message: 'To cite package "wrongurls" in publications use:'
      type: software
      title: 'wrongurls: Generate CodeMeta Metadata for R Packages'
      version: 0.1.0
      authors:
      - family-names: Boettiger
        given-names: Carl
        email: cboettig@gmail.com
      abstract: Codemeta defines a 'JSON-LD' format for describing software metadata. This
        package provides utilities to generate, parse, and modify codemeta.jsonld files
        automatically for R packages.
      url: https://httpbin.org/status/404
      contact:
      - family-names: Boettiger
        given-names: Carl
        email: cboettig@gmail.com
      keywords:
      - metadata
      - codemeta
      - ropensci
      - citation
      - credit
      - linked-data
      license: MIT
      doi: 10.1111/2041-210X.12469
      preferred-citation:
        type: article
        title: 'RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic,
          Character, and Trait Data in R'
        authors:
        - family-names: Boettiger
          given-names: Carl
        - family-names: Chamberlain
          given-names: Scott
        - family-names: Vos
          given-names: Rutger
        - family-names: Lapp
          given-names: Hilmar
        journal: Methods in Ecology and Evolution
        year: '2016'
        volume: '7'
        doi: 10.1111/2041-210X.12469
        start: '352'
        end: '357'
      identifiers:
      - type: url
        value: https://httpbin.org/status/429
      - type: url
        value: https://www.github.es/ropensci/codemeta
      references:
      - type: book
        title: 'ggplot2: Elegant Graphics for Data Analysis'
        authors:
        - family-names: Wickham
          given-names: Hadley
        publisher:
          name: Springer-Verlag New York
        year: '2016'
        isbn: 978-3-319-24277-4
        url: https://ggplot2.tidyverse.org

# Check dependencies

    Code
      print(selected)
    Output
      - title: 'R: A Language and Environment for Statistical Computing'
        url: https://www.R-project.org/
      - title: cli
        url: https://cli.r-lib.org
        repository: https://CRAN.R-project.org/package=cli
      - title: desc
        url: https://desc.r-lib.org/
        repository: https://CRAN.R-project.org/package=desc
      - title: jsonlite
        url: https://jeroen.r-universe.dev/jsonlite
        repository: https://CRAN.R-project.org/package=jsonlite
      - title: jsonvalidate
        url: https://docs.ropensci.org/jsonvalidate/
        repository: https://CRAN.R-project.org/package=jsonvalidate
      - title: tools
      - title: utils
      - title: yaml
        url: https://yaml.r-lib.org
        repository: https://CRAN.R-project.org/package=yaml
      - title: bibtex
        url: https://docs.ropensci.org/bibtex/
        repository: https://CRAN.R-project.org/package=bibtex
      - title: knitr
        url: https://yihui.org/knitr/
        repository: https://CRAN.R-project.org/package=knitr
      - title: lifecycle
        url: https://lifecycle.r-lib.org/
        repository: https://CRAN.R-project.org/package=lifecycle
      - title: quarto
        url: https://quarto-dev.github.io/quarto-r/
        repository: https://CRAN.R-project.org/package=quarto
      - title: rmarkdown
        url: https://pkgs.rstudio.com/rmarkdown/
        repository: https://CRAN.R-project.org/package=rmarkdown
      - title: testthat
        url: https://testthat.r-lib.org
        repository: https://CRAN.R-project.org/package=testthat
      - title: usethis
        url: https://usethis.r-lib.org
        repository: https://CRAN.R-project.org/package=usethis

