# as data frame complete

    Code
      names(the_df)
    Output
        [1] "cff_version"                                       
        [2] "message"                                           
        [3] "abstract"                                          
        [4] "authors.00.family_names"                           
        [5] "authors.00.given_names"                            
        [6] "authors.00.name_particle"                          
        [7] "authors.00.name_suffix"                            
        [8] "authors.00.alias"                                  
        [9] "authors.00.affiliation"                            
       [10] "authors.00.address"                                
       [11] "authors.00.city"                                   
       [12] "authors.00.region"                                 
       [13] "authors.00.post_code"                              
       [14] "authors.00.country"                                
       [15] "authors.00.orcid"                                  
       [16] "authors.00.email"                                  
       [17] "authors.00.tel"                                    
       [18] "authors.00.fax"                                    
       [19] "authors.00.website"                                
       [20] "authors.01.name"                                   
       [21] "authors.01.address"                                
       [22] "authors.01.city"                                   
       [23] "authors.01.region"                                 
       [24] "authors.01.post_code"                              
       [25] "authors.01.country"                                
       [26] "authors.01.orcid"                                  
       [27] "authors.01.email"                                  
       [28] "authors.01.tel"                                    
       [29] "authors.01.fax"                                    
       [30] "authors.01.website"                                
       [31] "authors.01.date_start"                             
       [32] "authors.01.date_end"                               
       [33] "authors.01.location"                               
       [34] "commit"                                            
       [35] "contact.00.family_names"                           
       [36] "contact.00.given_names"                            
       [37] "contact.00.name_particle"                          
       [38] "contact.00.name_suffix"                            
       [39] "contact.00.alias"                                  
       [40] "contact.00.affiliation"                            
       [41] "contact.00.address"                                
       [42] "contact.00.city"                                   
       [43] "contact.00.region"                                 
       [44] "contact.00.post_code"                              
       [45] "contact.00.country"                                
       [46] "contact.00.orcid"                                  
       [47] "contact.00.email"                                  
       [48] "contact.00.tel"                                    
       [49] "contact.00.fax"                                    
       [50] "contact.00.website"                                
       [51] "contact.01.name"                                   
       [52] "contact.01.address"                                
       [53] "contact.01.city"                                   
       [54] "contact.01.region"                                 
       [55] "contact.01.post_code"                              
       [56] "contact.01.country"                                
       [57] "contact.01.orcid"                                  
       [58] "contact.01.email"                                  
       [59] "contact.01.tel"                                    
       [60] "contact.01.fax"                                    
       [61] "contact.01.website"                                
       [62] "contact.01.date_start"                             
       [63] "contact.01.date_end"                               
       [64] "contact.01.location"                               
       [65] "date_released"                                     
       [66] "doi"                                               
       [67] "identifiers.00.type"                               
       [68] "identifiers.00.value"                              
       [69] "identifiers.01.type"                               
       [70] "identifiers.01.value"                              
       [71] "identifiers.02.type"                               
       [72] "identifiers.02.value"                              
       [73] "identifiers.03.type"                               
       [74] "identifiers.03.value"                              
       [75] "keywords.00"                                       
       [76] "keywords.01"                                       
       [77] "keywords.02"                                       
       [78] "keywords.03"                                       
       [79] "license"                                           
       [80] "license_url"                                       
       [81] "repository"                                        
       [82] "repository_code"                                   
       [83] "repository_artifact"                               
       [84] "title"                                             
       [85] "type"                                              
       [86] "url"                                               
       [87] "version"                                           
       [88] "preferred_citation.type"                           
       [89] "preferred_citation.title"                          
       [90] "preferred_citation.abbreviation"                   
       [91] "preferred_citation.abstract"                       
       [92] "preferred_citation.collection_doi"                 
       [93] "preferred_citation.collection_title"               
       [94] "preferred_citation.collection_type"                
       [95] "preferred_citation.commit"                         
       [96] "preferred_citation.copyright"                      
       [97] "preferred_citation.data_type"                      
       [98] "preferred_citation.database"                       
       [99] "preferred_citation.date_accessed"                  
      [100] "preferred_citation.date_downloaded"                
      [101] "preferred_citation.date_released"                  
      [102] "preferred_citation.date_published"                 
      [103] "preferred_citation.department"                     
      [104] "preferred_citation.doi"                            
      [105] "preferred_citation.edition"                        
      [106] "preferred_citation.end"                            
      [107] "preferred_citation.entry"                          
      [108] "preferred_citation.filename"                       
      [109] "preferred_citation.format"                         
      [110] "preferred_citation.identifiers.00.type"            
      [111] "preferred_citation.identifiers.00.value"           
      [112] "preferred_citation.identifiers.01.type"            
      [113] "preferred_citation.identifiers.01.value"           
      [114] "preferred_citation.identifiers.02.type"            
      [115] "preferred_citation.identifiers.02.value"           
      [116] "preferred_citation.identifiers.03.type"            
      [117] "preferred_citation.identifiers.03.value"           
      [118] "preferred_citation.isbn"                           
      [119] "preferred_citation.issn"                           
      [120] "preferred_citation.issue"                          
      [121] "preferred_citation.issue_date"                     
      [122] "preferred_citation.issue_title"                    
      [123] "preferred_citation.journal"                        
      [124] "preferred_citation.keywords.00"                    
      [125] "preferred_citation.keywords.01"                    
      [126] "preferred_citation.languages.00"                   
      [127] "preferred_citation.languages.01"                   
      [128] "preferred_citation.license"                        
      [129] "preferred_citation.license_url"                    
      [130] "preferred_citation.loc_start"                      
      [131] "preferred_citation.loc_end"                        
      [132] "preferred_citation.medium"                         
      [133] "preferred_citation.month"                          
      [134] "preferred_citation.nihmsid"                        
      [135] "preferred_citation.notes"                          
      [136] "preferred_citation.number"                         
      [137] "preferred_citation.number_volumes"                 
      [138] "preferred_citation.pages"                          
      [139] "preferred_citation.patent_states.00"               
      [140] "preferred_citation.patent_states.01"               
      [141] "preferred_citation.patent_states.02"               
      [142] "preferred_citation.patent_states.03"               
      [143] "preferred_citation.patent_states.04"               
      [144] "preferred_citation.pmcid"                          
      [145] "preferred_citation.repository"                     
      [146] "preferred_citation.repository_code"                
      [147] "preferred_citation.repository_artifact"            
      [148] "preferred_citation.scope"                          
      [149] "preferred_citation.section"                        
      [150] "preferred_citation.status"                         
      [151] "preferred_citation.start"                          
      [152] "preferred_citation.thesis_type"                    
      [153] "preferred_citation.url"                            
      [154] "preferred_citation.version"                        
      [155] "preferred_citation.volume"                         
      [156] "preferred_citation.volume_title"                   
      [157] "preferred_citation.year"                           
      [158] "preferred_citation.year_original"                  
      [159] "preferred_citation.conference.name"                
      [160] "preferred_citation.conference.address"             
      [161] "preferred_citation.conference.city"                
      [162] "preferred_citation.conference.region"              
      [163] "preferred_citation.conference.post_code"           
      [164] "preferred_citation.conference.country"             
      [165] "preferred_citation.conference.orcid"               
      [166] "preferred_citation.conference.email"               
      [167] "preferred_citation.conference.tel"                 
      [168] "preferred_citation.conference.fax"                 
      [169] "preferred_citation.conference.website"             
      [170] "preferred_citation.conference.date_start"          
      [171] "preferred_citation.conference.date_end"            
      [172] "preferred_citation.conference.location"            
      [173] "preferred_citation.authors.00.family_names"        
      [174] "preferred_citation.authors.00.given_names"         
      [175] "preferred_citation.authors.00.name_particle"       
      [176] "preferred_citation.authors.00.name_suffix"         
      [177] "preferred_citation.authors.00.alias"               
      [178] "preferred_citation.authors.00.affiliation"         
      [179] "preferred_citation.authors.00.address"             
      [180] "preferred_citation.authors.00.city"                
      [181] "preferred_citation.authors.00.region"              
      [182] "preferred_citation.authors.00.post_code"           
      [183] "preferred_citation.authors.00.country"             
      [184] "preferred_citation.authors.00.orcid"               
      [185] "preferred_citation.authors.00.email"               
      [186] "preferred_citation.authors.00.tel"                 
      [187] "preferred_citation.authors.00.fax"                 
      [188] "preferred_citation.authors.00.website"             
      [189] "preferred_citation.authors.01.name"                
      [190] "preferred_citation.authors.01.address"             
      [191] "preferred_citation.authors.01.city"                
      [192] "preferred_citation.authors.01.region"              
      [193] "preferred_citation.authors.01.post_code"           
      [194] "preferred_citation.authors.01.country"             
      [195] "preferred_citation.authors.01.orcid"               
      [196] "preferred_citation.authors.01.email"               
      [197] "preferred_citation.authors.01.tel"                 
      [198] "preferred_citation.authors.01.fax"                 
      [199] "preferred_citation.authors.01.website"             
      [200] "preferred_citation.authors.01.date_start"          
      [201] "preferred_citation.authors.01.date_end"            
      [202] "preferred_citation.authors.01.location"            
      [203] "preferred_citation.contact.00.family_names"        
      [204] "preferred_citation.contact.00.given_names"         
      [205] "preferred_citation.contact.00.name_particle"       
      [206] "preferred_citation.contact.00.name_suffix"         
      [207] "preferred_citation.contact.00.alias"               
      [208] "preferred_citation.contact.00.affiliation"         
      [209] "preferred_citation.contact.00.address"             
      [210] "preferred_citation.contact.00.city"                
      [211] "preferred_citation.contact.00.region"              
      [212] "preferred_citation.contact.00.post_code"           
      [213] "preferred_citation.contact.00.country"             
      [214] "preferred_citation.contact.00.orcid"               
      [215] "preferred_citation.contact.00.email"               
      [216] "preferred_citation.contact.00.tel"                 
      [217] "preferred_citation.contact.00.fax"                 
      [218] "preferred_citation.contact.00.website"             
      [219] "preferred_citation.contact.01.name"                
      [220] "preferred_citation.contact.01.address"             
      [221] "preferred_citation.contact.01.city"                
      [222] "preferred_citation.contact.01.region"              
      [223] "preferred_citation.contact.01.post_code"           
      [224] "preferred_citation.contact.01.country"             
      [225] "preferred_citation.contact.01.orcid"               
      [226] "preferred_citation.contact.01.email"               
      [227] "preferred_citation.contact.01.tel"                 
      [228] "preferred_citation.contact.01.fax"                 
      [229] "preferred_citation.contact.01.website"             
      [230] "preferred_citation.contact.01.date_start"          
      [231] "preferred_citation.contact.01.date_end"            
      [232] "preferred_citation.contact.01.location"            
      [233] "preferred_citation.database_provider.name"         
      [234] "preferred_citation.database_provider.address"      
      [235] "preferred_citation.database_provider.city"         
      [236] "preferred_citation.database_provider.region"       
      [237] "preferred_citation.database_provider.post_code"    
      [238] "preferred_citation.database_provider.country"      
      [239] "preferred_citation.database_provider.orcid"        
      [240] "preferred_citation.database_provider.email"        
      [241] "preferred_citation.database_provider.tel"          
      [242] "preferred_citation.database_provider.fax"          
      [243] "preferred_citation.database_provider.website"      
      [244] "preferred_citation.database_provider.date_start"   
      [245] "preferred_citation.database_provider.date_end"     
      [246] "preferred_citation.database_provider.location"     
      [247] "preferred_citation.editors.00.family_names"        
      [248] "preferred_citation.editors.00.given_names"         
      [249] "preferred_citation.editors.00.name_particle"       
      [250] "preferred_citation.editors.00.name_suffix"         
      [251] "preferred_citation.editors.00.alias"               
      [252] "preferred_citation.editors.00.affiliation"         
      [253] "preferred_citation.editors.00.address"             
      [254] "preferred_citation.editors.00.city"                
      [255] "preferred_citation.editors.00.region"              
      [256] "preferred_citation.editors.00.post_code"           
      [257] "preferred_citation.editors.00.country"             
      [258] "preferred_citation.editors.00.orcid"               
      [259] "preferred_citation.editors.00.email"               
      [260] "preferred_citation.editors.00.tel"                 
      [261] "preferred_citation.editors.00.fax"                 
      [262] "preferred_citation.editors.00.website"             
      [263] "preferred_citation.editors.01.name"                
      [264] "preferred_citation.editors.01.address"             
      [265] "preferred_citation.editors.01.city"                
      [266] "preferred_citation.editors.01.region"              
      [267] "preferred_citation.editors.01.post_code"           
      [268] "preferred_citation.editors.01.country"             
      [269] "preferred_citation.editors.01.orcid"               
      [270] "preferred_citation.editors.01.email"               
      [271] "preferred_citation.editors.01.tel"                 
      [272] "preferred_citation.editors.01.fax"                 
      [273] "preferred_citation.editors.01.website"             
      [274] "preferred_citation.editors.01.date_start"          
      [275] "preferred_citation.editors.01.date_end"            
      [276] "preferred_citation.editors.01.location"            
      [277] "preferred_citation.editors_series.00.family_names" 
      [278] "preferred_citation.editors_series.00.given_names"  
      [279] "preferred_citation.editors_series.00.name_particle"
      [280] "preferred_citation.editors_series.00.name_suffix"  
      [281] "preferred_citation.editors_series.00.alias"        
      [282] "preferred_citation.editors_series.00.affiliation"  
      [283] "preferred_citation.editors_series.00.address"      
      [284] "preferred_citation.editors_series.00.city"         
      [285] "preferred_citation.editors_series.00.region"       
      [286] "preferred_citation.editors_series.00.post_code"    
      [287] "preferred_citation.editors_series.00.country"      
      [288] "preferred_citation.editors_series.00.orcid"        
      [289] "preferred_citation.editors_series.00.email"        
      [290] "preferred_citation.editors_series.00.tel"          
      [291] "preferred_citation.editors_series.00.fax"          
      [292] "preferred_citation.editors_series.00.website"      
      [293] "preferred_citation.editors_series.01.name"         
      [294] "preferred_citation.editors_series.01.address"      
      [295] "preferred_citation.editors_series.01.city"         
      [296] "preferred_citation.editors_series.01.region"       
      [297] "preferred_citation.editors_series.01.post_code"    
      [298] "preferred_citation.editors_series.01.country"      
      [299] "preferred_citation.editors_series.01.orcid"        
      [300] "preferred_citation.editors_series.01.email"        
      [301] "preferred_citation.editors_series.01.tel"          
      [302] "preferred_citation.editors_series.01.fax"          
      [303] "preferred_citation.editors_series.01.website"      
      [304] "preferred_citation.editors_series.01.date_start"   
      [305] "preferred_citation.editors_series.01.date_end"     
      [306] "preferred_citation.editors_series.01.location"     
      [307] "preferred_citation.institution.name"               
      [308] "preferred_citation.institution.address"            
      [309] "preferred_citation.institution.city"               
      [310] "preferred_citation.institution.region"             
      [311] "preferred_citation.institution.post_code"          
      [312] "preferred_citation.institution.country"            
      [313] "preferred_citation.institution.orcid"              
      [314] "preferred_citation.institution.email"              
      [315] "preferred_citation.institution.tel"                
      [316] "preferred_citation.institution.fax"                
      [317] "preferred_citation.institution.website"            
      [318] "preferred_citation.institution.date_start"         
      [319] "preferred_citation.institution.date_end"           
      [320] "preferred_citation.institution.location"           
      [321] "preferred_citation.location.name"                  
      [322] "preferred_citation.location.address"               
      [323] "preferred_citation.location.city"                  
      [324] "preferred_citation.location.region"                
      [325] "preferred_citation.location.post_code"             
      [326] "preferred_citation.location.country"               
      [327] "preferred_citation.location.orcid"                 
      [328] "preferred_citation.location.email"                 
      [329] "preferred_citation.location.tel"                   
      [330] "preferred_citation.location.fax"                   
      [331] "preferred_citation.location.website"               
      [332] "preferred_citation.location.date_start"            
      [333] "preferred_citation.location.date_end"              
      [334] "preferred_citation.location.location"              
      [335] "preferred_citation.publisher.name"                 
      [336] "preferred_citation.publisher.address"              
      [337] "preferred_citation.publisher.city"                 
      [338] "preferred_citation.publisher.region"               
      [339] "preferred_citation.publisher.post_code"            
      [340] "preferred_citation.publisher.country"              
      [341] "preferred_citation.publisher.orcid"                
      [342] "preferred_citation.publisher.email"                
      [343] "preferred_citation.publisher.tel"                  
      [344] "preferred_citation.publisher.fax"                  
      [345] "preferred_citation.publisher.website"              
      [346] "preferred_citation.publisher.date_start"           
      [347] "preferred_citation.publisher.date_end"             
      [348] "preferred_citation.publisher.location"             
      [349] "preferred_citation.recipients.00.family_names"     
      [350] "preferred_citation.recipients.00.given_names"      
      [351] "preferred_citation.recipients.00.name_particle"    
      [352] "preferred_citation.recipients.00.name_suffix"      
      [353] "preferred_citation.recipients.00.alias"            
      [354] "preferred_citation.recipients.00.affiliation"      
      [355] "preferred_citation.recipients.00.address"          
      [356] "preferred_citation.recipients.00.city"             
      [357] "preferred_citation.recipients.00.region"           
      [358] "preferred_citation.recipients.00.post_code"        
      [359] "preferred_citation.recipients.00.country"          
      [360] "preferred_citation.recipients.00.orcid"            
      [361] "preferred_citation.recipients.00.email"            
      [362] "preferred_citation.recipients.00.tel"              
      [363] "preferred_citation.recipients.00.fax"              
      [364] "preferred_citation.recipients.00.website"          
      [365] "preferred_citation.recipients.01.name"             
      [366] "preferred_citation.recipients.01.address"          
      [367] "preferred_citation.recipients.01.city"             
      [368] "preferred_citation.recipients.01.region"           
      [369] "preferred_citation.recipients.01.post_code"        
      [370] "preferred_citation.recipients.01.country"          
      [371] "preferred_citation.recipients.01.orcid"            
      [372] "preferred_citation.recipients.01.email"            
      [373] "preferred_citation.recipients.01.tel"              
      [374] "preferred_citation.recipients.01.fax"              
      [375] "preferred_citation.recipients.01.website"          
      [376] "preferred_citation.recipients.01.date_start"       
      [377] "preferred_citation.recipients.01.date_end"         
      [378] "preferred_citation.recipients.01.location"         
      [379] "preferred_citation.senders.00.family_names"        
      [380] "preferred_citation.senders.00.given_names"         
      [381] "preferred_citation.senders.00.name_particle"       
      [382] "preferred_citation.senders.00.name_suffix"         
      [383] "preferred_citation.senders.00.alias"               
      [384] "preferred_citation.senders.00.affiliation"         
      [385] "preferred_citation.senders.00.address"             
      [386] "preferred_citation.senders.00.city"                
      [387] "preferred_citation.senders.00.region"              
      [388] "preferred_citation.senders.00.post_code"           
      [389] "preferred_citation.senders.00.country"             
      [390] "preferred_citation.senders.00.orcid"               
      [391] "preferred_citation.senders.00.email"               
      [392] "preferred_citation.senders.00.tel"                 
      [393] "preferred_citation.senders.00.fax"                 
      [394] "preferred_citation.senders.00.website"             
      [395] "preferred_citation.senders.01.name"                
      [396] "preferred_citation.senders.01.address"             
      [397] "preferred_citation.senders.01.city"                
      [398] "preferred_citation.senders.01.region"              
      [399] "preferred_citation.senders.01.post_code"           
      [400] "preferred_citation.senders.01.country"             
      [401] "preferred_citation.senders.01.orcid"               
      [402] "preferred_citation.senders.01.email"               
      [403] "preferred_citation.senders.01.tel"                 
      [404] "preferred_citation.senders.01.fax"                 
      [405] "preferred_citation.senders.01.website"             
      [406] "preferred_citation.senders.01.date_start"          
      [407] "preferred_citation.senders.01.date_end"            
      [408] "preferred_citation.senders.01.location"            
      [409] "preferred_citation.translators.00.family_names"    
      [410] "preferred_citation.translators.00.given_names"     
      [411] "preferred_citation.translators.00.name_particle"   
      [412] "preferred_citation.translators.00.name_suffix"     
      [413] "preferred_citation.translators.00.alias"           
      [414] "preferred_citation.translators.00.affiliation"     
      [415] "preferred_citation.translators.00.address"         
      [416] "preferred_citation.translators.00.city"            
      [417] "preferred_citation.translators.00.region"          
      [418] "preferred_citation.translators.00.post_code"       
      [419] "preferred_citation.translators.00.country"         
      [420] "preferred_citation.translators.00.orcid"           
      [421] "preferred_citation.translators.00.email"           
      [422] "preferred_citation.translators.00.tel"             
      [423] "preferred_citation.translators.00.fax"             
      [424] "preferred_citation.translators.00.website"         
      [425] "preferred_citation.translators.01.name"            
      [426] "preferred_citation.translators.01.address"         
      [427] "preferred_citation.translators.01.city"            
      [428] "preferred_citation.translators.01.region"          
      [429] "preferred_citation.translators.01.post_code"       
      [430] "preferred_citation.translators.01.country"         
      [431] "preferred_citation.translators.01.orcid"           
      [432] "preferred_citation.translators.01.email"           
      [433] "preferred_citation.translators.01.tel"             
      [434] "preferred_citation.translators.01.fax"             
      [435] "preferred_citation.translators.01.website"         
      [436] "preferred_citation.translators.01.date_start"      
      [437] "preferred_citation.translators.01.date_end"        
      [438] "preferred_citation.translators.01.location"        
      [439] "references.00.type"                                
      [440] "references.00.title"                               
      [441] "references.00.abbreviation"                        
      [442] "references.00.abstract"                            
      [443] "references.00.collection_doi"                      
      [444] "references.00.collection_title"                    
      [445] "references.00.collection_type"                     
      [446] "references.00.commit"                              
      [447] "references.00.copyright"                           
      [448] "references.00.data_type"                           
      [449] "references.00.database"                            
      [450] "references.00.date_accessed"                       
      [451] "references.00.date_downloaded"                     
      [452] "references.00.date_released"                       
      [453] "references.00.date_published"                      
      [454] "references.00.department"                          
      [455] "references.00.doi"                                 
      [456] "references.00.edition"                             
      [457] "references.00.end"                                 
      [458] "references.00.entry"                               
      [459] "references.00.filename"                            
      [460] "references.00.format"                              
      [461] "references.00.identifiers.00.type"                 
      [462] "references.00.identifiers.00.value"                
      [463] "references.00.identifiers.01.type"                 
      [464] "references.00.identifiers.01.value"                
      [465] "references.00.identifiers.02.type"                 
      [466] "references.00.identifiers.02.value"                
      [467] "references.00.identifiers.03.type"                 
      [468] "references.00.identifiers.03.value"                
      [469] "references.00.isbn"                                
      [470] "references.00.issn"                                
      [471] "references.00.issue"                               
      [472] "references.00.issue_date"                          
      [473] "references.00.issue_title"                         
      [474] "references.00.journal"                             
      [475] "references.00.keywords.00"                         
      [476] "references.00.keywords.01"                         
      [477] "references.00.languages.00"                        
      [478] "references.00.languages.01"                        
      [479] "references.00.license"                             
      [480] "references.00.license_url"                         
      [481] "references.00.loc_start"                           
      [482] "references.00.loc_end"                             
      [483] "references.00.medium"                              
      [484] "references.00.month"                               
      [485] "references.00.nihmsid"                             
      [486] "references.00.notes"                               
      [487] "references.00.number"                              
      [488] "references.00.number_volumes"                      
      [489] "references.00.pages"                               
      [490] "references.00.patent_states.00"                    
      [491] "references.00.patent_states.01"                    
      [492] "references.00.patent_states.02"                    
      [493] "references.00.patent_states.03"                    
      [494] "references.00.patent_states.04"                    
      [495] "references.00.pmcid"                               
      [496] "references.00.repository"                          
      [497] "references.00.repository_code"                     
      [498] "references.00.repository_artifact"                 
      [499] "references.00.scope"                               
      [500] "references.00.section"                             
      [501] "references.00.status"                              
      [502] "references.00.start"                               
      [503] "references.00.thesis_type"                         
      [504] "references.00.url"                                 
      [505] "references.00.version"                             
      [506] "references.00.volume"                              
      [507] "references.00.volume_title"                        
      [508] "references.00.year"                                
      [509] "references.00.year_original"                       
      [510] "references.00.conference.name"                     
      [511] "references.00.conference.address"                  
      [512] "references.00.conference.city"                     
      [513] "references.00.conference.region"                   
      [514] "references.00.conference.post_code"                
      [515] "references.00.conference.country"                  
      [516] "references.00.conference.orcid"                    
      [517] "references.00.conference.email"                    
      [518] "references.00.conference.tel"                      
      [519] "references.00.conference.fax"                      
      [520] "references.00.conference.website"                  
      [521] "references.00.conference.date_start"               
      [522] "references.00.conference.date_end"                 
      [523] "references.00.conference.location"                 
      [524] "references.00.authors.00.family_names"             
      [525] "references.00.authors.00.given_names"              
      [526] "references.00.authors.00.name_particle"            
      [527] "references.00.authors.00.name_suffix"              
      [528] "references.00.authors.00.alias"                    
      [529] "references.00.authors.00.affiliation"              
      [530] "references.00.authors.00.address"                  
      [531] "references.00.authors.00.city"                     
      [532] "references.00.authors.00.region"                   
      [533] "references.00.authors.00.post_code"                
      [534] "references.00.authors.00.country"                  
      [535] "references.00.authors.00.orcid"                    
      [536] "references.00.authors.00.email"                    
      [537] "references.00.authors.00.tel"                      
      [538] "references.00.authors.00.fax"                      
      [539] "references.00.authors.00.website"                  
      [540] "references.00.authors.01.name"                     
      [541] "references.00.authors.01.address"                  
      [542] "references.00.authors.01.city"                     
      [543] "references.00.authors.01.region"                   
      [544] "references.00.authors.01.post_code"                
      [545] "references.00.authors.01.country"                  
      [546] "references.00.authors.01.orcid"                    
      [547] "references.00.authors.01.email"                    
      [548] "references.00.authors.01.tel"                      
      [549] "references.00.authors.01.fax"                      
      [550] "references.00.authors.01.website"                  
      [551] "references.00.authors.01.date_start"               
      [552] "references.00.authors.01.date_end"                 
      [553] "references.00.authors.01.location"                 
      [554] "references.00.contact.00.family_names"             
      [555] "references.00.contact.00.given_names"              
      [556] "references.00.contact.00.name_particle"            
      [557] "references.00.contact.00.name_suffix"              
      [558] "references.00.contact.00.alias"                    
      [559] "references.00.contact.00.affiliation"              
      [560] "references.00.contact.00.address"                  
      [561] "references.00.contact.00.city"                     
      [562] "references.00.contact.00.region"                   
      [563] "references.00.contact.00.post_code"                
      [564] "references.00.contact.00.country"                  
      [565] "references.00.contact.00.orcid"                    
      [566] "references.00.contact.00.email"                    
      [567] "references.00.contact.00.tel"                      
      [568] "references.00.contact.00.fax"                      
      [569] "references.00.contact.00.website"                  
      [570] "references.00.contact.01.name"                     
      [571] "references.00.contact.01.address"                  
      [572] "references.00.contact.01.city"                     
      [573] "references.00.contact.01.region"                   
      [574] "references.00.contact.01.post_code"                
      [575] "references.00.contact.01.country"                  
      [576] "references.00.contact.01.orcid"                    
      [577] "references.00.contact.01.email"                    
      [578] "references.00.contact.01.tel"                      
      [579] "references.00.contact.01.fax"                      
      [580] "references.00.contact.01.website"                  
      [581] "references.00.contact.01.date_start"               
      [582] "references.00.contact.01.date_end"                 
      [583] "references.00.contact.01.location"                 
      [584] "references.00.database_provider.name"              
      [585] "references.00.database_provider.address"           
      [586] "references.00.database_provider.city"              
      [587] "references.00.database_provider.region"            
      [588] "references.00.database_provider.post_code"         
      [589] "references.00.database_provider.country"           
      [590] "references.00.database_provider.orcid"             
      [591] "references.00.database_provider.email"             
      [592] "references.00.database_provider.tel"               
      [593] "references.00.database_provider.fax"               
      [594] "references.00.database_provider.website"           
      [595] "references.00.database_provider.date_start"        
      [596] "references.00.database_provider.date_end"          
      [597] "references.00.database_provider.location"          
      [598] "references.00.editors.00.family_names"             
      [599] "references.00.editors.00.given_names"              
      [600] "references.00.editors.00.name_particle"            
      [601] "references.00.editors.00.name_suffix"              
      [602] "references.00.editors.00.alias"                    
      [603] "references.00.editors.00.affiliation"              
      [604] "references.00.editors.00.address"                  
      [605] "references.00.editors.00.city"                     
      [606] "references.00.editors.00.region"                   
      [607] "references.00.editors.00.post_code"                
      [608] "references.00.editors.00.country"                  
      [609] "references.00.editors.00.orcid"                    
      [610] "references.00.editors.00.email"                    
      [611] "references.00.editors.00.tel"                      
      [612] "references.00.editors.00.fax"                      
      [613] "references.00.editors.00.website"                  
      [614] "references.00.editors.01.name"                     
      [615] "references.00.editors.01.address"                  
      [616] "references.00.editors.01.city"                     
      [617] "references.00.editors.01.region"                   
      [618] "references.00.editors.01.post_code"                
      [619] "references.00.editors.01.country"                  
      [620] "references.00.editors.01.orcid"                    
      [621] "references.00.editors.01.email"                    
      [622] "references.00.editors.01.tel"                      
      [623] "references.00.editors.01.fax"                      
      [624] "references.00.editors.01.website"                  
      [625] "references.00.editors.01.date_start"               
      [626] "references.00.editors.01.date_end"                 
      [627] "references.00.editors.01.location"                 
      [628] "references.00.editors_series.00.family_names"      
      [629] "references.00.editors_series.00.given_names"       
      [630] "references.00.editors_series.00.name_particle"     
      [631] "references.00.editors_series.00.name_suffix"       
      [632] "references.00.editors_series.00.alias"             
      [633] "references.00.editors_series.00.affiliation"       
      [634] "references.00.editors_series.00.address"           
      [635] "references.00.editors_series.00.city"              
      [636] "references.00.editors_series.00.region"            
      [637] "references.00.editors_series.00.post_code"         
      [638] "references.00.editors_series.00.country"           
      [639] "references.00.editors_series.00.orcid"             
      [640] "references.00.editors_series.00.email"             
      [641] "references.00.editors_series.00.tel"               
      [642] "references.00.editors_series.00.fax"               
      [643] "references.00.editors_series.00.website"           
      [644] "references.00.editors_series.01.name"              
      [645] "references.00.editors_series.01.address"           
      [646] "references.00.editors_series.01.city"              
      [647] "references.00.editors_series.01.region"            
      [648] "references.00.editors_series.01.post_code"         
      [649] "references.00.editors_series.01.country"           
      [650] "references.00.editors_series.01.orcid"             
      [651] "references.00.editors_series.01.email"             
      [652] "references.00.editors_series.01.tel"               
      [653] "references.00.editors_series.01.fax"               
      [654] "references.00.editors_series.01.website"           
      [655] "references.00.editors_series.01.date_start"        
      [656] "references.00.editors_series.01.date_end"          
      [657] "references.00.editors_series.01.location"          
      [658] "references.00.institution.name"                    
      [659] "references.00.institution.address"                 
      [660] "references.00.institution.city"                    
      [661] "references.00.institution.region"                  
      [662] "references.00.institution.post_code"               
      [663] "references.00.institution.country"                 
      [664] "references.00.institution.orcid"                   
      [665] "references.00.institution.email"                   
      [666] "references.00.institution.tel"                     
      [667] "references.00.institution.fax"                     
      [668] "references.00.institution.website"                 
      [669] "references.00.institution.date_start"              
      [670] "references.00.institution.date_end"                
      [671] "references.00.institution.location"                
      [672] "references.00.location.name"                       
      [673] "references.00.location.address"                    
      [674] "references.00.location.city"                       
      [675] "references.00.location.region"                     
      [676] "references.00.location.post_code"                  
      [677] "references.00.location.country"                    
      [678] "references.00.location.orcid"                      
      [679] "references.00.location.email"                      
      [680] "references.00.location.tel"                        
      [681] "references.00.location.fax"                        
      [682] "references.00.location.website"                    
      [683] "references.00.location.date_start"                 
      [684] "references.00.location.date_end"                   
      [685] "references.00.location.location"                   
      [686] "references.00.publisher.name"                      
      [687] "references.00.publisher.address"                   
      [688] "references.00.publisher.city"                      
      [689] "references.00.publisher.region"                    
      [690] "references.00.publisher.post_code"                 
      [691] "references.00.publisher.country"                   
      [692] "references.00.publisher.orcid"                     
      [693] "references.00.publisher.email"                     
      [694] "references.00.publisher.tel"                       
      [695] "references.00.publisher.fax"                       
      [696] "references.00.publisher.website"                   
      [697] "references.00.publisher.date_start"                
      [698] "references.00.publisher.date_end"                  
      [699] "references.00.publisher.location"                  
      [700] "references.00.recipients.00.family_names"          
      [701] "references.00.recipients.00.given_names"           
      [702] "references.00.recipients.00.name_particle"         
      [703] "references.00.recipients.00.name_suffix"           
      [704] "references.00.recipients.00.alias"                 
      [705] "references.00.recipients.00.affiliation"           
      [706] "references.00.recipients.00.address"               
      [707] "references.00.recipients.00.city"                  
      [708] "references.00.recipients.00.region"                
      [709] "references.00.recipients.00.post_code"             
      [710] "references.00.recipients.00.country"               
      [711] "references.00.recipients.00.orcid"                 
      [712] "references.00.recipients.00.email"                 
      [713] "references.00.recipients.00.tel"                   
      [714] "references.00.recipients.00.fax"                   
      [715] "references.00.recipients.00.website"               
      [716] "references.00.recipients.01.name"                  
      [717] "references.00.recipients.01.address"               
      [718] "references.00.recipients.01.city"                  
      [719] "references.00.recipients.01.region"                
      [720] "references.00.recipients.01.post_code"             
      [721] "references.00.recipients.01.country"               
      [722] "references.00.recipients.01.orcid"                 
      [723] "references.00.recipients.01.email"                 
      [724] "references.00.recipients.01.tel"                   
      [725] "references.00.recipients.01.fax"                   
      [726] "references.00.recipients.01.website"               
      [727] "references.00.recipients.01.date_start"            
      [728] "references.00.recipients.01.date_end"              
      [729] "references.00.recipients.01.location"              
      [730] "references.00.senders.00.family_names"             
      [731] "references.00.senders.00.given_names"              
      [732] "references.00.senders.00.name_particle"            
      [733] "references.00.senders.00.name_suffix"              
      [734] "references.00.senders.00.alias"                    
      [735] "references.00.senders.00.affiliation"              
      [736] "references.00.senders.00.address"                  
      [737] "references.00.senders.00.city"                     
      [738] "references.00.senders.00.region"                   
      [739] "references.00.senders.00.post_code"                
      [740] "references.00.senders.00.country"                  
      [741] "references.00.senders.00.orcid"                    
      [742] "references.00.senders.00.email"                    
      [743] "references.00.senders.00.tel"                      
      [744] "references.00.senders.00.fax"                      
      [745] "references.00.senders.00.website"                  
      [746] "references.00.senders.01.name"                     
      [747] "references.00.senders.01.address"                  
      [748] "references.00.senders.01.city"                     
      [749] "references.00.senders.01.region"                   
      [750] "references.00.senders.01.post_code"                
      [751] "references.00.senders.01.country"                  
      [752] "references.00.senders.01.orcid"                    
      [753] "references.00.senders.01.email"                    
      [754] "references.00.senders.01.tel"                      
      [755] "references.00.senders.01.fax"                      
      [756] "references.00.senders.01.website"                  
      [757] "references.00.senders.01.date_start"               
      [758] "references.00.senders.01.date_end"                 
      [759] "references.00.senders.01.location"                 
      [760] "references.00.translators.00.family_names"         
      [761] "references.00.translators.00.given_names"          
      [762] "references.00.translators.00.name_particle"        
      [763] "references.00.translators.00.name_suffix"          
      [764] "references.00.translators.00.alias"                
      [765] "references.00.translators.00.affiliation"          
      [766] "references.00.translators.00.address"              
      [767] "references.00.translators.00.city"                 
      [768] "references.00.translators.00.region"               
      [769] "references.00.translators.00.post_code"            
      [770] "references.00.translators.00.country"              
      [771] "references.00.translators.00.orcid"                
      [772] "references.00.translators.00.email"                
      [773] "references.00.translators.00.tel"                  
      [774] "references.00.translators.00.fax"                  
      [775] "references.00.translators.00.website"              
      [776] "references.00.translators.01.name"                 
      [777] "references.00.translators.01.address"              
      [778] "references.00.translators.01.city"                 
      [779] "references.00.translators.01.region"               
      [780] "references.00.translators.01.post_code"            
      [781] "references.00.translators.01.country"              
      [782] "references.00.translators.01.orcid"                
      [783] "references.00.translators.01.email"                
      [784] "references.00.translators.01.tel"                  
      [785] "references.00.translators.01.fax"                  
      [786] "references.00.translators.01.website"              
      [787] "references.00.translators.01.date_start"           
      [788] "references.00.translators.01.date_end"             
      [789] "references.00.translators.01.location"             

# Convert a citation only

    Code
      names(the_df)
    Output
       [1] "references.00.type"                   
       [2] "references.00.title"                  
       [3] "references.00.authors.00.family_names"
       [4] "references.00.authors.00.given_names" 
       [5] "references.00.authors.00.email"       
       [6] "references.00.authors.00.orcid"       
       [7] "references.00.authors.01.family_names"
       [8] "references.00.authors.01.given_names" 
       [9] "references.00.authors.01.affiliation" 
      [10] "references.00.authors.01.country"     
      [11] "references.00.authors.02.family_names"
      [12] "references.00.authors.02.given_names" 
      [13] "references.00.authors.02.email"       
      [14] "references.00.authors.03.name"        
      [15] "references.00.authors.03.date_end"    
      [16] "references.00.url"                    
      [17] "references.00.abstract"               
      [18] "references.00.keywords.00"            
      [19] "references.00.keywords.01"            
      [20] "references.00.keywords.02"            
      [21] "references.00.keywords.03"            
      [22] "references.00.keywords.04"            
      [23] "references.00.keywords.05"            
      [24] "references.00.keywords.06"            
      [25] "references.00.keywords.07"            
      [26] "references.00.version"                

# Convert authors only

    Code
      names(the_df)
    Output
      [1] "family_names" "given_names" 

# Convert list of authors

    Code
      names(the_df)
    Output
       [1] "person.00.family_names"  "person.00.given_names"  
       [3] "person.00.name_particle" "person.00.name_suffix"  
       [5] "person.00.alias"         "person.00.affiliation"  
       [7] "person.00.address"       "person.00.city"         
       [9] "person.00.region"        "person.00.post_code"    
      [11] "person.00.country"       "person.00.orcid"        
      [13] "person.00.email"         "person.00.tel"          
      [15] "person.00.fax"           "person.00.website"      
      [17] "person.01.name"          "person.01.address"      
      [19] "person.01.city"          "person.01.region"       
      [21] "person.01.post_code"     "person.01.country"      
      [23] "person.01.orcid"         "person.01.email"        
      [25] "person.01.tel"           "person.01.fax"          
      [27] "person.01.website"       "person.01.date_start"   
      [29] "person.01.date_end"      "person.01.location"     

# as.person method

    Code
      dput(pub)
    Output
      structure(list(list(given = "Entity Project Team Conference entity", 
          family = NULL, role = NULL, email = "project@entity.com", 
          comment = c(address = "22 Acacia Avenue", city = "Citationburgh", 
          region = "Renfrewshire", `post-code` = "C13 7X7", country = "GB", 
          ORCID = "0000-0001-2345-6789", tel = "+44(0)141-323 4567", 
          fax = "+44(0)141-323 45678", website = "https://www.entity-project-team.io", 
          `date-start` = "2017-01-01", `date-end` = "2017-01-31", location = "The team garage"
          ))), class = "person")

---

    Code
      format(pub, include = c("given", "family", "email", "role", "comment"))
    Output
      [1] "Entity Project Team Conference entity <project@entity.com> (address: 22 Acacia Avenue, city: Citationburgh, region: Renfrewshire, post-code: C13 7X7, country: GB, ORCID: <https://orcid.org/0000-0001-2345-6789>, tel: +44(0)141-323 4567, fax: +44(0)141-323 45678, website: https://www.entity-project-team.io, date-start: 2017-01-01, date-end: 2017-01-31, location: The team garage)"

---

    Code
      dput(aut)
    Output
      structure(list(list(given = "One Truly", family = "van der Real Person, IV", 
          role = NULL, email = "project@entity.com", comment = c(alias = "Citey", 
          affiliation = "Excellent University, Niceplace, Arcadia", 
          address = "22 Acacia Avenue", city = "Citationburgh", region = "Renfrewshire", 
          `post-code` = "C13 7X7", country = "GB", ORCID = "0000-0001-2345-6789", 
          tel = "+44(0)141-323 4567", fax = "+44(0)141-323 45678", 
          website = "https://www.entity-project-team.io"))), class = "person")

---

    Code
      format(aut, include = c("given", "family", "email", "role", "comment"))
    Output
      [1] "One Truly van der Real Person, IV <project@entity.com> (alias: Citey, affiliation: Excellent University, Niceplace, Arcadia, address: 22 Acacia Avenue, city: Citationburgh, region: Renfrewshire, post-code: C13 7X7, country: GB, ORCID: <https://orcid.org/0000-0001-2345-6789>, tel: +44(0)141-323 4567, fax: +44(0)141-323 45678, website: https://www.entity-project-team.io)"

---

    Code
      dput(aut2)
    Output
      structure(list(list(given = "One Truly", family = "van der Real Person, IV", 
          role = NULL, email = "project@entity.com", comment = c(alias = "Citey", 
          affiliation = "Excellent University, Niceplace, Arcadia", 
          address = "22 Acacia Avenue", city = "Citationburgh", region = "Renfrewshire", 
          `post-code` = "C13 7X7", country = "GB", ORCID = "0000-0001-2345-6789", 
          tel = "+44(0)141-323 4567", fax = "+44(0)141-323 45678", 
          website = "https://www.entity-project-team.io")), list(given = "Entity Project Team Conference entity", 
          family = NULL, role = NULL, email = "project@entity.com", 
          comment = c(address = "22 Acacia Avenue", city = "Citationburgh", 
          region = "Renfrewshire", `post-code` = "C13 7X7", country = "GB", 
          ORCID = "0000-0001-2345-6789", tel = "+44(0)141-323 4567", 
          fax = "+44(0)141-323 45678", website = "https://www.entity-project-team.io", 
          `date-start` = "2017-01-01", `date-end` = "2017-01-31", location = "The team garage"
          ))), class = "person")

---

    Code
      end <- as.person(malf)
    Message
      i Can't create <person> for some elements of `x`.

---

    Code
      aa2 <- as.person(aa)
    Message
      i Removing duplicate <person> objects.

# as.person method names and particles

    Code
      cf
    Output
      - family-names: Wicksteed
        given-names: P. H.
        name-particle: von
        name-suffix: III
      - name: The translator factory

# Errors on other as.person methods

    Code
      as.person(the_cff)
    Condition
      Error in `as.person()`:
      ! (cffr) `as.person.cff()` method not implemented yet.

---

    Code
      as.person(key)
    Condition
      Error in `as.person()`:
      ! (cffr) `as.person.cff_ref_lst()` method not implemented yet.

---

    Code
      as.person(key)
    Condition
      Error in `as.person()`:
      ! (cffr) `as.person.cff_ref()` method not implemented yet.

# head and tail

    Code
      a_cff
    Output
      cff-version: 1.2.0
      message: If you use this software, please cite it using these metadata.
      title: My Research Software
      authors:
      - family-names: Doe
        given-names: John

---

    Code
      head(a_cff, 2)
    Output
      cff-version: 1.2.0
      message: If you use this software, please cite it using these metadata.

---

    Code
      tail(a_cff, 2)
    Output
      title: My Research Software
      authors:
      - family-names: Doe
        given-names: John

# toBibtex

    Code
      toBibtex(full_cff)
    Output
      @Misc{druskat_etall:2021,
        title = {Citation File Format},
        author = {Stephan Druskat and Jurriaan H. Spaaks and Neil {Chue Hong} and Robert Haines and James Baker and Spencer Bliven and Egon Willighagen and David Pérez-Suárez and Alexander Konovalov},
        year = {2021},
        month = {aug},
        doi = {10.5281/zenodo.5171937},
        url = {https://github.com/citation-file-format/citation-file-format},
        abstract = {The Citation File Format lets you provide citation metadata for software or datasets in plaintext files that are easy to read by both humans and machines.},
        urldate = {2021-11-07},
      }

---

    Code
      toBibtex(full_cff, what = "references")
    Output
      @Article{hernangomez:2021,
        title = {cffr: Generate Citation File Format Metadata for R Packages},
        author = {Diego Hernangómez},
        year = {2021},
        journal = {Journal of Open Source Software},
        publisher = {The Open Journal},
        volume = {6},
        number = {67},
        pages = {3900},
        doi = {10.21105/joss.03900},
        url = {https://doi.org/10.21105/joss.03900},
        note = {Publisher: The Open Journal},
      }
      
      @Article{boettiger_etall:2016,
        title = {RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic, Character, and Trait Data in R},
        author = {Carl Boettiger and Scott Chamberlain and Rutger Vos and Hilmar Lapp},
        year = {2016},
        journal = {Methods in Ecology and Evolution},
        volume = {7},
        pages = {352--357},
        doi = {10.1111/2041-210X.12469},
      }
      
      @Book{wickham:2016,
        title = {ggplot2: Elegant Graphics for Data Analysis},
        author = {Hadley Wickham},
        year = {2016},
        publisher = {Springer-Verlag New York},
        isbn = {978-3-319-24277-4},
        url = {https://ggplot2.tidyverse.org},
      }

---

    Code
      toBibtex(full_cff, what = "all")
    Output
      @Misc{druskat_etall:2021,
        title = {Citation File Format},
        author = {Stephan Druskat and Jurriaan H. Spaaks and Neil {Chue Hong} and Robert Haines and James Baker and Spencer Bliven and Egon Willighagen and David Pérez-Suárez and Alexander Konovalov},
        year = {2021},
        month = {aug},
        doi = {10.5281/zenodo.5171937},
        url = {https://github.com/citation-file-format/citation-file-format},
        abstract = {The Citation File Format lets you provide citation metadata for software or datasets in plaintext files that are easy to read by both humans and machines.},
        urldate = {2021-11-07},
      }
      
      @Article{hernangomez:2021,
        title = {cffr: Generate Citation File Format Metadata for R Packages},
        author = {Diego Hernangómez},
        year = {2021},
        journal = {Journal of Open Source Software},
        publisher = {The Open Journal},
        volume = {6},
        number = {67},
        pages = {3900},
        doi = {10.21105/joss.03900},
        url = {https://doi.org/10.21105/joss.03900},
        note = {Publisher: The Open Journal},
      }
      
      @Article{boettiger_etall:2016,
        title = {RNeXML: A Package for Reading and Writing Richly Annotated Phylogenetic, Character, and Trait Data in R},
        author = {Carl Boettiger and Scott Chamberlain and Rutger Vos and Hilmar Lapp},
        year = {2016},
        journal = {Methods in Ecology and Evolution},
        volume = {7},
        pages = {352--357},
        doi = {10.1111/2041-210X.12469},
      }
      
      @Book{wickham:2016,
        title = {ggplot2: Elegant Graphics for Data Analysis},
        author = {Hadley Wickham},
        year = {2016},
        publisher = {Springer-Verlag New York},
        isbn = {978-3-319-24277-4},
        url = {https://ggplot2.tidyverse.org},
      }

